==> 0ad-data_0.0.13.orig.tar.xz: simulation/ai/tutorial-ai/economic_walkthrough.js <==
var economic_walkthrough = [
			{
				"instructions": "Warning: This is an advanced tutorial and goes quite fast.  If you don't keep up just restart and try again.  Practise makes perfect!",
			},
			{
				"trigger": "time",
				"time": 0,
				"instructions": "Lets get started, first train a batch (shift click) of 5 female citizens from the CC (Civil Centre)."
			},
			{
				"trigger": "time",
				"time": 5,
				"instructions": "Now, assign your female citizens to gather berries, your cavalryman to hunt the chickens and the citizen soldiers to gather wood."
			},
			{
				"trigger": "time",
				"time": 15,
				"instructions": "Now set the rally point of your civil centre on the berries"
			},
			{
				"trigger": "time",
				"time": 23,
				"instructions": "Queue some slingers to train after the female citizens, you won't have enough resources for a batch."
			},
			{
				"trigger": "time",
				"time": 30,
				"instructions": "When your female citizens have finished training, use 4 to build a house nearby."
			},
			{
				"trigger": "time",
				"time": 38,
				"instructions": "Set the CC's rally point on the nearby trees, queue more slingers, you want to train 6 right now."
			},
			{
				"trigger": "time",
				"time": 70,
				"instructions": "Queue a batch of 5 female citizens."
			},
			{
				"trigger": "time",
				"time": 75,
				"instructions": "Use shift-click to queue another house for the 4 builders."
			},
			{
				"trigger": "time",
				"time": 85,
				"instructions": "Set the rally point back to the berries once all of the citizen soldiers have finished training."
			},
			{
				"trigger": "time",
				"time": 95,
				"instructions": "Send one citizen soldier to gather stone, send 2 others to build a mill near the southern trees."
			},
			{
				"trigger": "time",
				"time": 100,
				"instructions": "Queue another 5 female citizens."
			},
			{
				"trigger": "time",
				"time": 107,
				"instructions": "Use a female citizen to construct a field next to your CC."
			},
			{
				"trigger": "time",
				"time": 110,
				"instructions": "Your cavalryman has probably run out of chickens by now, there are some goats to the left of your base."
			},
			{
				"trigger": "time",
				"time": 115,
				"instructions": "Use 2-3 more female citizens to contruct the field"
			},
			{
				"trigger": "time",
				"time": 130,
				"instructions": "Queue another 5 female citizens"
			},
			{
				"trigger": "time",
				"time": 135,
				"instructions": "Queue another house."
			},
			{
				"trigger": "time",
				"time": 145,
				"instructions": "The berry bushes are getting crowded, send some female citizens to work the field, set the rally point there."
			},
			{
				"trigger": "time",
				"time": 160,
				"instructions": "Queue another 5 female citizens, these should gather stone"
			},
			{
				"trigger": "time",
				"time": 170,
				"instructions": "Move your woodcutters to the trees near the mill so they dont have to walk as far."
			},
			{
				"trigger": "time",
				"time": 175,
				"instructions": "Make sure the workers from the berry bushes are used to gather from the field rather than standing idle when they run out."
			},
			{
				"trigger": "time",
				"time": 190,
				"instructions": "Queue another house to be built."
			},
			{
				"trigger": "time",
				"time": 195,
				"instructions": "Queue 5 more female citizens.  These will gather wood"
			},
			{
				"trigger": "time",
				"time": 220,
				"instructions": "Build another field, this decreases the amount of walking for your female citizens."
			},
			{
				"trigger": "time",
				"time": 220,
				"instructions": "Train some more slingers, send them to gather stone.  train about 5, you may not have enough resources for a batch right now."
			},
			{
				"trigger": "time",
				"time": 231,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 260,
				"instructions": "Queue another batch of 5 female citizens these are for wood. "
			},
			{
				"trigger": "time",
				"time": 285,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 290,
				"instructions": "Queue a batch of spearmen"
			},
			{
				"trigger": "time",
				"time": 295,
				"instructions": "Research the stone mining technology from the mill."
			},
			{
				"trigger": "time",
				"time": 300,
				"instructions": "Queue a batch of slingers"
			},
			{
				"trigger": "time",
				"time": 310,
				"instructions": "Move 3 women from wood and 3 from stone to farming.  Women are cheap to train initially but later in the game it is best to maxinmize efficiency as you are able to train more citizen soldiers."
			},
			{
				"trigger": "time",
				"time": 325,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 330,
				"instructions": "The slingers that you queue earlier should gather stone once they are trained."
			},
			{
				"trigger": "time",
				"time": 340,
				"instructions": "Queue a batch of spearmen, they should gather wood."
			},
			{
				"trigger": "time",
				"time": 360,
				"instructions": "Next queue a batch of slingers"
			},
			{
				"trigger": "time",
				"time": 390,
				"instructions": "Send some of the stone miners to mine metal, getting ready for the next age."
			},
			{
				"trigger": "time",
				"time": 400,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 410,
				"instructions": "Start researching Phase 2"
			},
			{
				"trigger": "time",
				"time": 430,
				"instructions": "Queue some slingers"
			},
			{
				"trigger": "time",
				"time": 435,
				"instructions": "Your fields may start getting exhausted, remember to rebuild them."
			},
			{
				"trigger": "time",
				"time": 440,
				"instructions": "When you have advanced, use a single citizen soldier to place a barracks foundation.  Then use the rest of the non food or house building female citizens to construct it."
			},
			{
				"trigger": "time",
				"time": 458,
				"instructions": "Queue 5 more females for construction work."
			},
			{
				"trigger": "time",
				"time": 480,
				"instructions": "Queue a batch of slingers to gather the trees on the north side of your base."
			},
			{
				"trigger": "time",
				"time": 490,
				"instructions": "This is the end of the walkthrough.  This should give you a good idea of how to build up a nice economy rapidly."
			},
			{
				"trigger": "time",
				"time": 500,
				"instructions": "At this point you should be able to fully use both training facilities, keep putting units into economic work, to keep growing faster and faster."
			},
			{
				"trigger": "time",
				"time": 505,
				"instructions": "From this point you have a good base to build an army and wipe out the opposition."
			},
			{
				"trigger": "time",
				"time": 510,
				"instructions": "The key points to remember are: "
			},
			{
				"trigger": "time",
				"time": 513,
				"instructions": " - Don't have any idle units.  Shift click queueing and rally points are very useful."
			},
			{
				"trigger": "time",
				"time": 516,
				"instructions": " - Use all of your resources, stockpiled resources are waste, having too much of a resource is waste."
			},
			{
				"trigger": "time",
				"time": 519,
				"instructions": " - Use the right units for the right task, female citizens gather food, cavalry hunt, citizen soldiers do the rest."
			},
			{
				"trigger": "time",
				"time": 522,
				"instructions": " - Don't be afraid to swap units from one resource to another, see point 2.  Make sure they deposit what they are carrying first though."
			},
			{
				"trigger": "time",
				"time": 525,
				"instructions": " - Build enough houses, your CC should be kept busy as much as possible, it is the only training building until town phase."
			},
			{
				"trigger": "time",
				"time": 528,
				"instructions": " - Female citizens are cheap, so you can build more of them and gather more resources."
			},
			{
				"trigger": "time",
				"time": 531,
				"instructions": " - Don't get carried away on the last point or you will get raided and have no defence."
			},
			{
				"trigger": "time",
				"time": 538,
				"instructions": "Each map is different, so you will need to play slightly differently on each.  This should give an outline for a high resource map."
			},
		]

==> 0ad-data_0.0.15.orig.tar.xz: simulation/ai/tutorial-ai/economic_walkthrough.js <==
var economic_walkthrough = [
			{
				"instructions": "Warning: This is an advanced tutorial and goes quite fast.  If you don't keep up just restart and try again.  Practise makes perfect!",
			},
			{
				"trigger": "time",
				"time": 0,
				"instructions": "Lets get started, first train a batch (shift click) of 5 female citizens from the CC (Civil Centre)."
			},
			{
				"trigger": "time",
				"time": 5,
				"instructions": "Now, assign your female citizens to gather berries, your cavalryman to hunt the chickens and the citizen soldiers to gather wood."
			},
			{
				"trigger": "time",
				"time": 15,
				"instructions": "Now set the rally point of your civil centre on the berries"
			},
			{
				"trigger": "time",
				"time": 23,
				"instructions": "Queue some slingers to train after the female citizens, you won't have enough resources for a batch."
			},
			{
				"trigger": "time",
				"time": 30,
				"instructions": "When your female citizens have finished training, use 4 to build a house nearby."
			},
			{
				"trigger": "time",
				"time": 38,
				"instructions": "Set the CC's rally point on the nearby trees, queue more slingers, you want to train 6 right now."
			},
			{
				"trigger": "time",
				"time": 70,
				"instructions": "Queue a batch of 5 female citizens."
			},
			{
				"trigger": "time",
				"time": 75,
				"instructions": "Use shift-click to queue another house for the 4 builders."
			},
			{
				"trigger": "time",
				"time": 85,
				"instructions": "Set the rally point back to the berries once all of the citizen soldiers have finished training."
			},
			{
				"trigger": "time",
				"time": 95,
				"instructions": "Send one citizen soldier to gather stone, send 2 others to build a storehouse near the southern trees."
			},
			{
				"trigger": "time",
				"time": 100,
				"instructions": "Queue another 5 female citizens."
			},
			{
				"trigger": "time",
				"time": 107,
				"instructions": "Use a female citizen to construct a field next to your CC."
			},
			{
				"trigger": "time",
				"time": 110,
				"instructions": "Your cavalryman has probably run out of chickens by now, there are some goats to the left of your base."
			},
			{
				"trigger": "time",
				"time": 115,
				"instructions": "Use 2-3 more female citizens to contruct the field"
			},
			{
				"trigger": "time",
				"time": 130,
				"instructions": "Queue another 5 female citizens"
			},
			{
				"trigger": "time",
				"time": 135,
				"instructions": "Queue another house."
			},
			{
				"trigger": "time",
				"time": 145,
				"instructions": "The berry bushes are getting crowded, send some female citizens to work the field, set the rally point there."
			},
			{
				"trigger": "time",
				"time": 160,
				"instructions": "Queue another 5 female citizens, these should gather stone"
			},
			{
				"trigger": "time",
				"time": 170,
				"instructions": "Move your woodcutters to the trees near the storehouse so they dont have to walk as far."
			},
			{
				"trigger": "time",
				"time": 175,
				"instructions": "Make sure the workers from the berry bushes are used to gather from the field rather than standing idle when they run out."
			},
			{
				"trigger": "time",
				"time": 190,
				"instructions": "Queue another house to be built."
			},
			{
				"trigger": "time",
				"time": 195,
				"instructions": "Queue 5 more female citizens.  These will gather wood"
			},
			{
				"trigger": "time",
				"time": 220,
				"instructions": "Build another field, this decreases the amount of walking for your female citizens."
			},
			{
				"trigger": "time",
				"time": 220,
				"instructions": "Train some more slingers, send them to gather stone.  train about 5, you may not have enough resources for a batch right now."
			},
			{
				"trigger": "time",
				"time": 231,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 260,
				"instructions": "Queue another batch of 5 female citizens these are for wood. "
			},
			{
				"trigger": "time",
				"time": 285,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 290,
				"instructions": "Queue a batch of spearmen"
			},
			{
				"trigger": "time",
				"time": 295,
				"instructions": "Research the stone mining technology from the storehouse."
			},
			{
				"trigger": "time",
				"time": 300,
				"instructions": "Queue a batch of slingers"
			},
			{
				"trigger": "time",
				"time": 310,
				"instructions": "Move 3 women from wood and 3 from stone to farming.  Women are cheap to train initially but later in the game it is best to maxinmize efficiency as you are able to train more citizen soldiers."
			},
			{
				"trigger": "time",
				"time": 325,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 330,
				"instructions": "The slingers that you queue earlier should gather stone once they are trained."
			},
			{
				"trigger": "time",
				"time": 340,
				"instructions": "Queue a batch of spearmen, they should gather wood."
			},
			{
				"trigger": "time",
				"time": 360,
				"instructions": "Next queue a batch of slingers"
			},
			{
				"trigger": "time",
				"time": 390,
				"instructions": "Send some of the stone miners to mine metal, getting ready for the next age."
			},
			{
				"trigger": "time",
				"time": 400,
				"instructions": "Queue another house"
			},
			{
				"trigger": "time",
				"time": 410,
				"instructions": "Start researching Phase 2"
			},
			{
				"trigger": "time",
				"time": 430,
				"instructions": "Queue some slingers"
			},
			{
				"trigger": "time",
				"time": 435,
				"instructions": "Your fields may start getting exhausted, remember to rebuild them."
			},
			{
				"trigger": "time",
				"time": 440,
				"instructions": "When you have advanced, use a single citizen soldier to place a barracks foundation.  Then use the rest of the non food or house building female citizens to construct it."
			},
			{
				"trigger": "time",
				"time": 458,
				"instructions": "Queue 5 more females for construction work."
			},
			{
				"trigger": "time",
				"time": 480,
				"instructions": "Queue a batch of slingers to gather the trees on the north side of your base."
			},
			{
				"trigger": "time",
				"time": 490,
				"instructions": "This is the end of the walkthrough.  This should give you a good idea of how to build up a nice economy rapidly."
			},
			{
				"trigger": "time",
				"time": 500,
				"instructions": "At this point you should be able to fully use both training facilities, keep putting units into economic work, to keep growing faster and faster."
			},
			{
				"trigger": "time",
				"time": 505,
				"instructions": "From this point you have a good base to build an army and wipe out the opposition."
			},
			{
				"trigger": "time",
				"time": 510,
				"instructions": "The key points to remember are: "
			},
			{
				"trigger": "time",
				"time": 513,
				"instructions": " - Don't have any idle units.  Shift click queueing and rally points are very useful."
			},
			{
				"trigger": "time",
				"time": 516,
				"instructions": " - Use all of your resources, stockpiled resources are waste, having too much of a resource is waste."
			},
			{
				"trigger": "time",
				"time": 519,
				"instructions": " - Use the right units for the right task, female citizens gather food, cavalry hunt, citizen soldiers do the rest."
			},
			{
				"trigger": "time",
				"time": 522,
				"instructions": " - Don't be afraid to swap units from one resource to another, see point 2.  Make sure they deposit what they are carrying first though."
			},
			{
				"trigger": "time",
				"time": 525,
				"instructions": " - Build enough houses, your CC should be kept busy as much as possible, it is the only training building until town phase."
			},
			{
				"trigger": "time",
				"time": 528,
				"instructions": " - Female citizens are cheap, so you can build more of them and gather more resources."
			},
			{
				"trigger": "time",
				"time": 531,
				"instructions": " - Don't get carried away on the last point or you will get raided and have no defence."
			},
			{
				"trigger": "time",
				"time": 538,
				"instructions": "Each map is different, so you will need to play slightly differently on each.  This should give an outline for a high resource map."
			},
		]
